@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
@@ -69,7 +68,7 @@ class MQTTDaemonTestCase(TestCase):
         client = mock.MagicMock()
 
         # pylint: disable=unused-variable
-        daemon = MQTTDaemon(client)
+        daemon = MQTTDaemon(client)  # noqa: F841
 
         client.connect.assert_called_with()
 
